Author: bugman
Date: Fri Aug 29 14:53:37 2014
New Revision: 25431

URL: http://svn.gna.org/viewcvs/relax?rev=25431&view=rev
Log:
Better error checking in the relaxation dispersion overfit_deselect() API 
method.

The model must be set for this procedure to work, and the method now checks 
that this is the case.


Modified:
    trunk/specific_analyses/relax_disp/api.py

Modified: trunk/specific_analyses/relax_disp/api.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/specific_analyses/relax_disp/api.py?rev=25431&r1=25430&r2=25431&view=diff
==============================================================================
--- trunk/specific_analyses/relax_disp/api.py   (original)
+++ trunk/specific_analyses/relax_disp/api.py   Fri Aug 29 14:53:37 2014
@@ -777,8 +777,9 @@
         @type verbose:          bool
         """
 
         # Test the sequence data exists.
         check_mol_res_spin_data()
+        check_model_type()
 
         # 1H MMQ flag.
         proton_mmq_flag = has_proton_mmq_cpmg()
@@ -777,8 +777,9 @@
         """
 
-        # Test the sequence data exists.
+        # Test the sequence data exists and the model is setup.
         check_mol_res_spin_data()


_______________________________________________
relax (http://www.nmr-relax.com)

This is the relax-commits mailing list
[email protected]

To unsubscribe from this list, get a password
reminder, or change your subscription options,
visit the list information page at
https://mail.gna.org/listinfo/relax-commits

Reply via email to